@@ -1,17 +1,16 @@
-from tqdm import *
-from time import sleep
+from tqdm import tqdm,trange
 import time
 from random import randint,choice
-from os import *
+# from os import *
+import os
 from termcolor import colored
 import f61d.LOGO as LOGO
 #from f61d.__version__ import *
 from math import ceil
-from tqdm import *
 from f61d.setu import *
 
 
-VERSION = (0,5,10)
+VERSION = (0,5,11)
 VERSION = '.'.join(map(str, VERSION))
 
 
@@ -84,11 +83,11 @@ def fuckStar():
             a,b = b,1
     for i in range(3):
         print('.',end='')
-        sleep(0.4)
+        time.sleep(0.4)
     if randint(1,100) > 80 or num == 'CHY':
         for i in range(3):
             print(colored('.','green'),end='')
-            sleep(0.4)
+            time.sleep(0.4)
         print(colored('\n日卫星成功.','green'))    
     else:
         print(colored('\n日卫星失败，请重新尝试','red'))
@@ -155,7 +154,7 @@ def prove(cont,process_bar=True,show_description=False):
 
     >>> r = remote("127.0.0.1",6666)
     >>> PoW = r.recvuntil(">")
-    >>> r.sendline(f61d.prove(PoW.encode()))
+    >>> r.sendline(f61d.prove(PoW))
     >>> r.interactive()
         
     '''
@@ -165,7 +164,9 @@ def prove(cont,process_bar=True,show_description=False):
     import re
     from string import ascii_letters,digits
     from hashlib import sha256
-    from tqdm import tqdm
+
+    if type(cont) == bytes:
+        cont = cont.decode()
     
     cont = cont.replace(' ','')
     #print(cont)
@@ -189,7 +190,7 @@ def prove(cont,process_bar=True,show_description=False):
         if process_bar and show_description:bar.set_description(f"trying: {S}")
         if ss(S+a) == b:
             print('\nFind ,',S)
-            return S
+            return S.encode()
     else:
         print('Failed to find \'XXXX\'')
         return None
@@ -232,6 +233,9 @@ def gmgj(n, c1, c2, e1, e2):#共模攻击
 def crt(c_list,n_list):
     '''
         Chinese Remainder Theory
+        x = c0 mod n0
+        x = c1 mod n1
+        ...
     '''
     from functools import reduce
     from gmpy2 import invert
